documentationtools.ReSTDocument
===============================

.. abjad-lineage:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument

.. autoclass:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.append
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.children
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.depth
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.depthwise_inventory
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.extend
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.graph_order
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.improper_parentage
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.index
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.insert
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.leaves
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.name
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.node_class
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.nodes
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.parent
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.pop
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.proper_parentage
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.remove
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.rest_format
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.root
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__contains__
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__copy__
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__deepcopy__
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__delitem__
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__eq__
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__format__
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__getitem__
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__iter__
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__len__
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__ne__
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__repr__
      ~abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__setitem__

Bases
-----

- :py:class:`datastructuretools.TreeContainer <abjad.tools.datastructuretools.TreeContainer.TreeContainer>`

- :py:class:`datastructuretools.TreeNode <abjad.tools.datastructuretools.TreeNode.TreeNode>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.children
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.leaves
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.node_class
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.nodes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.rest_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.root
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.append
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.extend
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.index
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.insert
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.pop
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.remove
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__contains__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__copy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__deepcopy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__delitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__format__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__getitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__iter__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__len__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.__setitem__
   :noindex:
